{% extends "site_base.html" %}
{% load staticfiles i18n %}
{% block extra_head %}
{{ block.super }}
<link rel="stylesheet" href="{% static "schedule/css/schedule.css" %}" type="text/css" media="screen" />
<link rel="stylesheet" href="{% static "schedule/css/jquery-ui.css" %}" type="text/css" media="screen" />
<script type="text/javascript" src="{% static "schedule/js/jquery.js" %}"></script>
<script type="text/javascript" src="{% static "schedule/js/jquery-ui.js" %}"></script>
{% endblock %}

{% block rtab_id %}id="schedule_tab"{% endblock %}

{% block subnav %}
<ul>
    {% if user.is_authenticated %}
        <li><a href="">{% trans "Create a Calendar" %}</a></li>
        <li><a href="">{% trans "Your Calendars" %}</a></li>
    {% endif %}

        <li><a href="">{% trans "All Calendars" %}</a></li>
    </ul>
{% endblock %}
